@@ -2,6 +2,8 @@
 import jinja2
 import wsgi
 from config import cfg
+from os.path import normpath, join, getmtime
+from os import getcwd
 
 def load_template(fn):
     ERR_MSG = 'template not found: %s' % fn
@@ -13,7 +15,10 @@ def load_template(fn):
             f = open('%s/templates/%s' % (app_name, fn))
         except (IOError, ValueError):
             assert 0, ERR_MSG
-    return f.read().decode('utf-8')
+
+    path = normpath(join(getcwd(), f.name))
+    mtime = getmtime(path)
+    return f.read().decode('utf-8'), path, lambda: mtime == getmtime(path)
 
 def render_to_string(fn, context):
     global _ENV
